@@ -1,15 +1,20 @@
-from __future__ import absolute_import
+# -*- coding: utf-8 -*-
 import logging
 
-# pylint: disable=wildcard-import
+# pylint: disable=redefined-builtin, undefined-variable
 from .communications import *
+from .communicate import *
+from .exceptions import *
 from .filters import *
 from .futures import *
 from .local import *
 from .utils import *
 from .version import *
 
-__all__ = (futures.__all__ + communications.__all__ + version.__all__ + utils.__all__ + local.__all__ + filters.__all__)
+__all__ = (
+    exceptions.__all__ + futures.__all__ + communications.__all__ + version.__all__ + utils.__all__ + local.__all__ +
+    filters.__all__ + communicate.__all__
+)
 
 
 # Do this se we don't get the "No handlers could be found..." warnings that will be produced
@@ -22,4 +27,4 @@ class NullHandler(logging.Handler):
         pass
 
 
-logging.getLogger("kiwipy").addHandler(NullHandler())
+logging.getLogger('kiwipy').addHandler(NullHandler())
