@@ -1,8 +1,7 @@
-from __future__ import absolute_import
-
+# -*- coding: utf-8 -*-
 from . import communications
 
-__all__ = ['LocalCommunicator']
+__all__ = ('LocalCommunicator',)
 
 
 class LocalCommunicator(communications.CommunicatorHelper):
