@@ -18,7 +18,7 @@ MESSAGE_TTL = 66 * SECONDS_TO_MILLISECONDS
 TEST_QUEUE_EXPIRES = 10 * SECONDS_TO_MILLISECONDS
 QUEUE_EXPIRES = 60 * SECONDS_TO_MILLISECONDS
 REPLY_QUEUE_EXPIRES = 60 * SECONDS_TO_MILLISECONDS
-TASK_MESSAGE_TTL = 60 * SECONDS_TO_MILLISECONDS * 60 * 24 * 7 * 120  # 120 days
+TASK_MESSAGE_TTL = 60 * SECONDS_TO_MILLISECONDS * 60 * 24 * 7  # 7 days
 TASK_PREFETCH_SIZE = 0
 TASK_PREFETCH_COUNT = 0
 TASK_FETCH_TIMEOUT = 5.
